abacusai.deployment_statistics — AbacusAI documentation

# abacusai.deployment_statistics

## Classes

`DeploymentStatistics` | A set of statistics for a realtime deployment.

## Module Contents

class abacusai.deployment_statistics.DeploymentStatistics(client, requestSeries=None, latencySeries=None, dateLabels=None, httpStatusSeries=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A set of statistics for a realtime deployment.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - requestSeries (list) – A list of the number of requests per second.

    - latencySeries (list) – A list of the latency in milliseconds for each request.

    - dateLabels (list) – A list of date labels for each point in the series.

    - httpStatusSeries (list) – A list of the HTTP status codes for each request.

  request_series = None
  latency_series = None
  date_labels = None
  http_status_series = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict